﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Security.Cryptography;
using System.Text;
using System.Threading.Tasks;

namespace Priprema
{
    public class Person : IComparable<Person>
    {
        private const char Del = '|';
        public string FirstName { get; set; }
        public string LastName { get; set; }

        public string OIB {
            get; 
            set; 
        }

        public string Phone { get; set; }
        public string Email { get; set; }

        public override string ToString()
        {
            return $"{OIB}:{FirstName}:{LastName}:{Phone}:{Email}";
        }

        public static Person Parse(string s)
        {
            string[] properties = s.Split(Del);
            return new Person
            {
                OIB = properties[0],
                FirstName = properties.Length > 1 ? properties[1] : String.Empty,
                LastName = properties.Length > 2 ? properties[2] : String.Empty,
                Phone = properties.Length > 3 ? properties[3] : String.Empty,
                Email = properties.Length > 4 ? properties[4] : String.Empty,
            };
        }

        public string Format()
        {
            return $"{OIB}{Del}{FirstName}{Del}{LastName}{Del}{Phone}{Del}{Email}";
        }

        public override bool Equals(object obj)
        {
            return obj is Person person &&
                   OIB == person.OIB;
        }

        public override int GetHashCode()
        {
            return 818605693 + EqualityComparer<string>.Default.GetHashCode(OIB);
        }

        public int CompareTo(Person other)
        {
            return OIB.CompareTo(other.OIB);
        }

        public bool HasValidOib()
        {
            return OIB.Length == 11 && OIB.All(char.IsDigit);
        }
    }
}
